@@ -309,6 +309,27 @@ class VectorConverter {
   ArrayBuilder* builder_;
 };
 
+class NullVectorConverter : public VectorConverter {
+ public:
+  using BuilderType = NullBuilder;
+
+  ~NullVectorConverter() {}
+
+  Status Init(ArrayBuilder* builder) override {
+    builder_ = builder;
+    typed_builder_ = checked_cast<BuilderType*>(builder_);
+    return Status::OK();
+  }
+
+  Status Ingest(SEXP obj) override {
+    RETURN_NOT_OK(typed_builder_->AppendNulls(XLENGTH(obj)));
+    return Status::OK();
+  }
+
+ protected:
+  BuilderType* typed_builder_;
+};
+
 template <typename Type, typename Enable = void>
 struct Unbox {};
 
@@ -380,7 +401,7 @@ struct Unbox<DoubleType> {
       if (*p == NA_INTEGER) {
         builder->UnsafeAppendNull();
       } else {
-        double value;
+        double value = 0;
         RETURN_NOT_OK(internal::double_cast(*p, &value));
         builder->UnsafeAppend(value);
       }
@@ -766,6 +787,10 @@ Status GetConverter(const std::shared_ptr<DataType>& type,
     TIME_CONVERTER_CASE(TIME64, Time64Type, Time64Converter);
     TIME_CONVERTER_CASE(TIMESTAMP, TimestampType, TimestampConverter);
 
+    case Type::NA:
+      *out = std::unique_ptr<NullVectorConverter>(new NullVectorConverter);
+      return Status::OK();
+
     default:
       break;
   }
@@ -800,6 +825,9 @@ std::shared_ptr<arrow::DataType> InferType(SEXP x) {
       }
       break;
     case LGLSXP:
+      if (Rf_inherits(x, "vctrs_unspecified")) {
+        return null();
+      }
       return boolean();
     case INTSXP:
       if (Rf_isFactor(x)) {
@@ -974,7 +1002,7 @@ arrow::Status CheckCompatibleStruct(SEXP obj,
 }
 
 std::shared_ptr<arrow::Array> Array__from_vector(
-    SEXP x, const std::shared_ptr<arrow::DataType>& type, bool type_infered) {
+    SEXP x, const std::shared_ptr<arrow::DataType>& type, bool type_inferred) {
   // short circuit if `x` is already an Array
   if (Rf_inherits(x, "Array")) {
     return Rcpp::ConstReferenceSmartPtrInputParameter<std::shared_ptr<arrow::Array>>(x);
@@ -992,9 +1020,9 @@ std::shared_ptr<arrow::Array> Array__from_vector(
     return arrow::r::MakeStringArray(x);
   }
 
-  // factors only when type has been infered
+  // factors only when type has been inferred
   if (type->id() == Type::DICTIONARY) {
-    if (type_infered || arrow::r::CheckCompatibleFactor(x, type)) {
+    if (type_inferred || arrow::r::CheckCompatibleFactor(x, type)) {
       return arrow::r::MakeFactorArray(x, type);
     }
 
@@ -1003,7 +1031,7 @@ std::shared_ptr<arrow::Array> Array__from_vector(
 
   // struct types
   if (type->id() == Type::STRUCT) {
-    if (!type_infered) {
+    if (!type_inferred) {
       STOP_IF_NOT_OK(arrow::r::CheckCompatibleStruct(x, type));
     }
 
@@ -1038,16 +1066,16 @@ std::shared_ptr<arrow::DataType> Array__infer_type(SEXP x) {
 // [[arrow::export]]
 std::shared_ptr<arrow::Array> Array__from_vector(SEXP x, SEXP s_type) {
   // the type might be NULL, in which case we need to infer it from the data
-  // we keep track of whether it was infered or supplied
-  bool type_infered = Rf_isNull(s_type);
+  // we keep track of whether it was inferred or supplied
+  bool type_inferred = Rf_isNull(s_type);
   std::shared_ptr<arrow::DataType> type;
-  if (type_infered) {
+  if (type_inferred) {
     type = arrow::r::InferType(x);
   } else {
     type = arrow::r::extract<arrow::DataType>(s_type);
   }
 
-  return arrow::r::Array__from_vector(x, type, type_infered);
+  return arrow::r::Array__from_vector(x, type, type_inferred);
 }
 
 // [[arrow::export]]
@@ -1056,12 +1084,12 @@ std::shared_ptr<arrow::ChunkedArray> ChunkedArray__from_list(Rcpp::List chunks,
   std::vector<std::shared_ptr<arrow::Array>> vec;
 
   // the type might be NULL, in which case we need to infer it from the data
-  // we keep track of whether it was infered or supplied
-  bool type_infered = Rf_isNull(s_type);
+  // we keep track of whether it was inferred or supplied
+  bool type_inferred = Rf_isNull(s_type);
   R_xlen_t n = XLENGTH(chunks);
 
   std::shared_ptr<arrow::DataType> type;
-  if (type_infered) {
+  if (type_inferred) {
     if (n == 0) {
       Rcpp::stop("type must be specified for empty list");
     }
@@ -1078,11 +1106,11 @@ std::shared_ptr<arrow::ChunkedArray> ChunkedArray__from_list(Rcpp::List chunks,
     vec.push_back(array);
   } else {
     // the first - might differ from the rest of the loop
-    // because we might have infered the type from the first element of the list
+    // because we might have inferred the type from the first element of the list
     //
     // this only really matters for dictionary arrays
     vec.push_back(
-        arrow::r::Array__from_vector(VECTOR_ELT(chunks, 0), type, type_infered));
+        arrow::r::Array__from_vector(VECTOR_ELT(chunks, 0), type, type_inferred));
 
     for (R_xlen_t i = 1; i < n; i++) {
       vec.push_back(arrow::r::Array__from_vector(VECTOR_ELT(chunks, i), type, false));
@@ -1092,4 +1120,14 @@ std::shared_ptr<arrow::ChunkedArray> ChunkedArray__from_list(Rcpp::List chunks,
   return std::make_shared<arrow::ChunkedArray>(std::move(vec));
 }
 
+// [[arrow::export]]
+std::shared_ptr<arrow::Array> DictionaryArray__FromArrays(
+    const std::shared_ptr<arrow::DataType>& type,
+    const std::shared_ptr<arrow::Array>& indices,
+    const std::shared_ptr<arrow::Array>& dict) {
+  std::shared_ptr<arrow::Array> out;
+  STOP_IF_NOT_OK(arrow::DictionaryArray::FromArrays(type, indices, dict, &out));
+  return out;
+}
+
 #endif
