@@ -47,18 +47,8 @@ struct data {
     if (!(TEST)) Rcpp::stop(MSG); \
   } while (0)
 
-#define STOP_IF_NOT_OK(s) STOP_IF_NOT(s.ok(), s.ToString())
-
-#define ARROW_ASSIGN_OR_STOP_IMPL(status_name, lhs, rexpr) \
-  auto status_name = (rexpr);                              \
-  if (!status_name.status().ok()) {                        \
-    Rcpp::stop(status_name.status().ToString());           \
-  }                                                        \
-  lhs = std::move(status_name).ValueOrDie();
-
-#define ARROW_ASSIGN_OR_STOP(lhs, rexp)                                               \
-  ARROW_ASSIGN_OR_STOP_IMPL(ARROW_ASSIGN_OR_RAISE_NAME(_error_or_value, __COUNTER__), \
-                            lhs, rexp)
+#define STOP_IF_NOT_OK(status) StopIfNotOk(status)
+#define VALUE_OR_STOP(result) ValueOrStop(result)
 
 template <typename T>
 struct NoDelete {
@@ -90,6 +80,24 @@ class ConstReferenceSmartPtrInputParameter {
   const T* ptr;
 };
 
+template <typename T>
+class ConstReferenceVectorSmartPtrInputParameter {
+ public:
+  using const_reference = const std::vector<T>&;
+
+  explicit ConstReferenceVectorSmartPtrInputParameter(SEXP self) : vec() {
+    R_xlen_t n = XLENGTH(self);
+    for (R_xlen_t i = 0; i < n; i++) {
+      vec.push_back(*internal::r6_to_smart_pointer<const T*>(VECTOR_ELT(self, i)));
+    }
+  }
+
+  inline operator const_reference() { return vec; }
+
+ private:
+  std::vector<T> vec;
+};
+
 namespace traits {
 
 template <typename T>
@@ -102,6 +110,12 @@ struct input_parameter<const std::unique_ptr<T>&> {
   typedef typename Rcpp::ConstReferenceSmartPtrInputParameter<std::unique_ptr<T>> type;
 };
 
+template <typename T>
+struct input_parameter<const std::vector<std::shared_ptr<T>>&> {
+  typedef typename Rcpp::ConstReferenceVectorSmartPtrInputParameter<std::shared_ptr<T>>
+      type;
+};
+
 struct wrap_type_shared_ptr_tag {};
 struct wrap_type_unique_ptr_tag {};
 
@@ -184,6 +198,7 @@ inline std::shared_ptr<T> extract(SEXP x) {
 #include <arrow/api.h>
 #include <arrow/compute/api.h>
 #include <arrow/csv/reader.h>
+#include <arrow/dataset/api.h>
 #include <arrow/filesystem/filesystem.h>
 #include <arrow/filesystem/localfs.h>
 #include <arrow/io/compressed.h>
@@ -193,6 +208,7 @@ inline std::shared_ptr<T> extract(SEXP x) {
 #include <arrow/ipc/reader.h>
 #include <arrow/ipc/writer.h>
 #include <arrow/json/reader.h>
+#include <arrow/result.h>
 #include <arrow/type.h>
 #include <arrow/util/compression.h>
 #include <parquet/arrow/reader.h>
@@ -215,13 +231,29 @@ std::shared_ptr<arrow::Array> Array__from_vector(SEXP x, SEXP type);
 std::shared_ptr<arrow::RecordBatch> RecordBatch__from_arrays(SEXP, SEXP);
 std::shared_ptr<arrow::RecordBatch> RecordBatch__from_dataframe(Rcpp::DataFrame tbl);
 
+namespace ds = ::arrow::dataset;
+namespace fs = ::arrow::fs;
+
 namespace arrow {
+
+template <typename R>
+auto ValueOrStop(R&& result) -> decltype(std::forward<R>(result).ValueOrDie()) {
+  STOP_IF_NOT_OK(result.status());
+  return std::forward<R>(result).ValueOrDie();
+}
+
+static inline void StopIfNotOk(const Status& status) {
+  if (!(status.ok())) {
+    Rcpp::stop(status.ToString());
+  }
+}
+
 namespace r {
 
 Status count_fields(SEXP lst, int* out);
 
 std::shared_ptr<arrow::Array> Array__from_vector(
-    SEXP x, const std::shared_ptr<arrow::DataType>& type, bool type_infered);
+    SEXP x, const std::shared_ptr<arrow::DataType>& type, bool type_inferred);
 
 template <typename T>
 std::vector<std::shared_ptr<T>> List_to_shared_ptr_vector(SEXP x) {
@@ -252,6 +284,8 @@ class RBuffer : public MutableBuffer {
   Vec vec_;
 };
 
+std::shared_ptr<arrow::DataType> GetFactorType(SEXP);
+
 }  // namespace r
 }  // namespace arrow
 
