@@ -55,13 +55,13 @@ std::shared_ptr<arrow::DataType> ChunkedArray__type(
 }
 
 // [[arrow::export]]
-std::shared_ptr<arrow::ChunkedArray> ChunkArray__Slice1(
+std::shared_ptr<arrow::ChunkedArray> ChunkedArray__Slice1(
     const std::shared_ptr<arrow::ChunkedArray>& chunked_array, int offset) {
   return chunked_array->Slice(offset);
 }
 
 // [[arrow::export]]
-std::shared_ptr<arrow::ChunkedArray> ChunkArray__Slice2(
+std::shared_ptr<arrow::ChunkedArray> ChunkedArray__Slice2(
     const std::shared_ptr<arrow::ChunkedArray>& chunked_array, int offset, int length) {
   return chunked_array->Slice(offset, length);
 }
