@@ -17,12 +17,20 @@
 
 context("General checks")
 
-if (identical(Sys.getenv("TEST_R_WITH_ARROW"), "TRUE")) {
+if (identical(tolower(Sys.getenv("TEST_R_WITH_ARROW")), "true")) {
   testthat::test_that("Arrow C++ is available", {
     expect_true(arrow_available())
   })
 }
 
+test_that("Can't $new() an object with anything other than a pointer", {
+  expect_error(
+    Array$new(1:5),
+    "Array$new() requires a pointer as input: did you mean $create() instead?",
+    fixed = TRUE
+  )
+})
+
 r_only({
   test_that("assert_is", {
     x <- 42
