@@ -22,6 +22,33 @@ test_that("Alternate type names are supported", {
     schema(b = double(), c = bool(), d = string(), e = float(), f = halffloat()),
     schema(b = float64(), c = boolean(), d = utf8(), e = float32(), f = float16())
   )
+  expect_equal(names(schema(b = double(), c = bool(), d = string())), c("b", "c", "d"))
+})
+
+test_that("Schema print method", {
+  expect_output(
+    print(schema(b = double(), c = bool(), d = string())),
+    paste(
+      "Schema",
+      "b: double",
+      "c: bool",
+      "d: string",
+      sep = "\n"
+    ),
+    fixed = TRUE
+  )
+})
+
+test_that("Schema $metadata when there is none", {
+  expect_null(schema(b = double())$metadata)
+})
+
+test_that("Schema $GetFieldByName", {
+  schm <- schema(b = double(), c = string())
+  expect_equal(schm$GetFieldByName("b"), field("b", double()))
+  expect_null(schm$GetFieldByName("f"))
+  # TODO: schema(b = double(), b = string())$GetFieldByName("b")
+  # also returns NULL and probably should error bc duplicated names
 })
 
 test_that("reading schema from Buffer", {
@@ -53,8 +80,8 @@ test_that("reading schema from Buffer", {
 })
 
 test_that("Input validation when creating a table with a schema", {
-  # TODO (npr): consider using table_from_dots once ARROW-5505 lands, and also
-  # allowing a list of types as a schema here
-  expect_error(Table__from_dots(list(b = 1), schema = c(b = float64())),
-    "schema must be an arrow::Schema or NULL")
+  expect_error(
+    Table$create(b = 1, schema = c(b = float64())), # list not Schema
+    "schema must be an arrow::Schema or NULL"
+  )
 })
